#!/bin/bash
#
# source: http://flomertens.free.fr/disk-manager/download/source/disk-manager-1.0.1.tar.gz
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------Set Some Variables

soft="disk-manager"
softversion="1.0.1"
arch="i486"
cpu="i686"
packageversion="64.1"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#------------------Set correct permissions

cd $src
cat $buildir/disk-manager-1.0.1.diff | patch -p1 --verbose
cat $buildir/01-fix_paths.patch | patch -p1 --verbose
cat $buildir/03-fix_translation.patch | patch -p1 --verbose
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
 --prefix=/usr \
 --sysconfdir=/etc

make -j2
make install DESTDIR=$dest

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

mv $dest/usr/share/man $dest/usr
gzip -9 $dest/usr/man/man?/*.?

#-------------------Prepare the documentation:

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING INSTALL NEWS README TODO $dest/usr/doc/$soft-$softversion

rm $dest/usr/share/applications/disk-manager.desktop
cat << EOF > $dest/usr/share/applications/disk-manager.desktop
[Desktop Entry]
Encoding=UTF-8
Version=1.0
Name=Disk Manager
Name[de]=Geräte Verwaltung
Name[en_GB]=Disk Manager
Name[es]=Administrador de disco
Name[fr]=Gestionnaire de disque
Name[nb]=Disk Manager
Name[pl]=Disk Manager
Name[pt_BR]=Gerenciador de Disco
Name[sv]=Diskhanterare
Name[zh_CN]=磁盘管理器
Comment=Manage filesystem configuration
Comment[de]=Verwalte Dateisystem Konfiguration
Comment[en_GB]=Manage filesystem configuration
Comment[es]=Administra la configuración del sistema de archivos
Comment[fr]=Gère la configuration du système de fichier
Comment[nb]=Styr filsystem konfigurasjon
Comment[pl]=Zarządaj konfiguracją systemu plików
Comment[pt_BR]=Gerenciar configurações do sistema de arquivos
Comment[sv]=Hantera filsystemskonfiguration
Comment[zh_CN]=管理文件系统的配置
Icon=disk-manager
Exec=gksu /usr/sbin/disk-manager-root
Terminal=false
Type=Application
NoDisplay=true
Categories=Application;System;Settings;X-Zenpanel;
EOF

#-----------------Make the slack-desc files

mkdir $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

            |-----handy-ruler--------------------------------------------------|
disk-manager: disk-manager - allow you to manage easily your partitions.
disk-manager:
disk-manager: Disk Manager allow you to manage easily your partitions.Current
disk-manager: features of the project are :
disk-manager: - Automatic detection of new partitions at startup.
disk-manager: - Full management of file system configuration.
disk-manager: - Enable/disable write support for NTFS (need ntfs-3g installed)
disk-manager:
disk-manager:
disk-manager:
disk-manager:
EODESC

cat << EOF > $dest/install/doinst.sh
if [ -x /usr/bin/gtk-update-icon-cache ]; then
  /usr/bin/gtk-update-icon-cache -f -t usr/share/icons/hicolor > /dev/null 2>&1
fi
EOF

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.txz > $package.md5